All Classes and Interfaces

Class
Description
The Enum Algorithm.
The Crypter combines Encrypter and Decrypter functionality.
Thrown in case an decryption issue occurred regarding the encoding.
Plain interface for providing straight forward decryption functionality as of Decrypter.toDecrypted(Object) and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework's CipherSpi as of Decrypter.toDecrypted(byte[], int, int, byte[], int).
Thrown in case an decryption issue occurred regarding the Encrypter.
Thrown in case an decryption issue occurred regarding the Encrypter.
A DecryptionInputStream wraps an InputStream and consumes input bytes by applying a Decrypter on each byte read from the provided InputStream before passing back the processed byte to the caller.
Thrown in case an encryption issue occurred regarding the encoding.
Plain interface for providing straight forward encryption functionality as of Encrypter.toEncrypted(Object) and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework's CipherSpi as of Encrypter.toEncrypted(byte[], int, int, byte[], int).
Thrown in case an encryption issue occurred regarding the Encrypter.
Thrown in case an encryption issue occurred regarding the Encrypter.
A EncryptionOutputStream wraps an OutputStream and produces output bytes by applying a Encrypter on each byte to be written before delegating the processed vale to the given OutputStream.
The immutable KeyStoreDescriptor implements the TrustStoreDescriptor interface.
Provides an accessor for a KeyStoreDescriptor property.
Provides a builder method for a KeyStoreDescriptor property returning the builder for applying multiple build operations.
Provides a mutator for a KeyStoreDescriptor property.
Provides a KeyStoreDescriptor property.
The PasswordTextDecrypter is a text Decrypter for decrypting String instances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.
The PasswordTextEncrypter is a text Encrypter for encrypting String instances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.
The Class SecurityRuntimeException.
The Enum StoreType.
Describes the data required to access a truststore.
Provides an accessor for a TrustStoreDescriptor property.
Provides a builder method for a TrustStoreDescriptor property returning the builder for applying multiple build operations.
Provides a mutator for a TrustStoreDescriptor property.
Provides a TrustStoreDescriptor property.