Index

A C D E F G H J K L M O P R S T V W _ 
All Classes and Interfaces|All Packages|Serialized Form

A

AES - Enum constant in enum class org.refcodes.security.Algorithm
 
Algorithm - Enum Class in org.refcodes.security
The Enum Algorithm.
available() - Method in class org.refcodes.security.DecryptionInputStream

C

close() - Method in class org.refcodes.security.DecryptionInputStream
close() - Method in class org.refcodes.security.EncryptionOutputStream
Crypter<ENC,DEC,ENCEXC,DECEXC> - Interface in org.refcodes.security
The Crypter combines Encrypter and Decrypter functionality.

D

decrypt(byte[]) - Method in interface org.refcodes.security.Decrypter
This method decrypts the provided buffer.
decrypt(byte[], int, int) - Method in interface org.refcodes.security.Decrypter
This method decrypts the provided buffer beginning at the given offset and the given number of bytes.
DecryptEncodingException - Exception Class in org.refcodes.security
Thrown in case an decryption issue occurred regarding the encoding.
DecryptEncodingException(String, String) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
DecryptEncodingException(String, String, String) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
DecryptEncodingException(String, String, Throwable) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
DecryptEncodingException(String, String, Throwable, String) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
DecryptEncodingException(String, Throwable) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
DecryptEncodingException(String, Throwable, String) - Constructor for exception class org.refcodes.security.DecryptEncodingException
 
Decrypter<DEC,ENC,EXC> - Interface in org.refcodes.security
Plain interface for providing straight forward decryption functionality as of Decrypter.toDecrypted(Object) and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework's CipherSpi as of Decrypter.toDecrypted(byte[], int, int, byte[], int).
DecryptionException - Exception Class in org.refcodes.security
Thrown in case an decryption issue occurred regarding the Encrypter.
DecryptionException(String) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException(String, String) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException(String, Throwable) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException(String, Throwable, String) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException(Throwable) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException(Throwable, String) - Constructor for exception class org.refcodes.security.DecryptionException
 
DecryptionException.DecryptionRuntimeException - Exception Class in org.refcodes.security
Thrown in case an decryption issue occurred regarding the Encrypter.
DecryptionInputStream - Class in org.refcodes.security
A DecryptionInputStream wraps an InputStream and consumes input bytes by applying a Decrypter on each byte read from the provided InputStream before passing back the processed byte to the caller.
DecryptionInputStream(InputStream, Decrypter) - Constructor for class org.refcodes.security.DecryptionInputStream
Constructs the DecryptionInputStream by wrapping the given InputStream for the provided Decrypter to be applied on the bytes to be read.
DecryptionRuntimeException(String) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
DecryptionRuntimeException(String, String) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
DecryptionRuntimeException(String, Throwable) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
DecryptionRuntimeException(String, Throwable, String) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
DecryptionRuntimeException(Throwable) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
DecryptionRuntimeException(Throwable, String) - Constructor for exception class org.refcodes.security.DecryptionException.DecryptionRuntimeException
 
dispose() - Method in class org.refcodes.security.DecryptionInputStream
dispose() - Method in class org.refcodes.security.EncryptionOutputStream
dispose() - Method in class org.refcodes.security.KeyStoreDescriptor
dispose() - Method in class org.refcodes.security.PasswordTextDecrypter
dispose() - Method in class org.refcodes.security.PasswordTextEncrypter
dispose() - Method in class org.refcodes.security.TrustStoreDescriptor

E

encrypt(byte[]) - Method in interface org.refcodes.security.Encrypter
This method encrypts the provided buffer.
encrypt(byte[], int, int) - Method in interface org.refcodes.security.Encrypter
This method encrypts the provided buffer beginning at the given offset and the given number of bytes.
EncryptEncodingException - Exception Class in org.refcodes.security
Thrown in case an encryption issue occurred regarding the encoding.
EncryptEncodingException(String, String) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
EncryptEncodingException(String, String, String) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
EncryptEncodingException(String, String, Throwable) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
EncryptEncodingException(String, String, Throwable, String) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
EncryptEncodingException(String, Throwable) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
EncryptEncodingException(String, Throwable, String) - Constructor for exception class org.refcodes.security.EncryptEncodingException
 
Encrypter<ENC,DEC,EXC> - Interface in org.refcodes.security
Plain interface for providing straight forward encryption functionality as of Encrypter.toEncrypted(Object) and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework's CipherSpi as of Encrypter.toEncrypted(byte[], int, int, byte[], int).
EncryptionException - Exception Class in org.refcodes.security
Thrown in case an encryption issue occurred regarding the Encrypter.
EncryptionException(String) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException(String, String) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException(String, Throwable) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException(String, Throwable, String) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException(Throwable) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException(Throwable, String) - Constructor for exception class org.refcodes.security.EncryptionException
 
EncryptionException.EncryptionRuntimeException - Exception Class in org.refcodes.security
Thrown in case an encryption issue occurred regarding the Encrypter.
EncryptionOutputStream - Class in org.refcodes.security
A EncryptionOutputStream wraps an OutputStream and produces output bytes by applying a Encrypter on each byte to be written before delegating the processed vale to the given OutputStream.
EncryptionOutputStream(OutputStream, Encrypter) - Constructor for class org.refcodes.security.EncryptionOutputStream
Constructs the EncryptionOutputStream by wrapping the given OutputStream for the provided Encrypter to be applied on the bytes to be written.
EncryptionRuntimeException(String) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
EncryptionRuntimeException(String, String) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
EncryptionRuntimeException(String, Throwable) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
EncryptionRuntimeException(String, Throwable, String) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
EncryptionRuntimeException(Throwable) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
EncryptionRuntimeException(Throwable, String) - Constructor for exception class org.refcodes.security.EncryptionException.EncryptionRuntimeException
 
equals(Object) - Method in class org.refcodes.security.DecryptionInputStream
equals(Object) - Method in class org.refcodes.security.EncryptionOutputStream

F

flush() - Method in class org.refcodes.security.EncryptionOutputStream

G

getEncoding() - Method in exception class org.refcodes.security.DecryptEncodingException
getEncoding() - Method in exception class org.refcodes.security.EncryptEncodingException
getKeyPassword() - Method in class org.refcodes.security.KeyStoreDescriptor
Retrieves the key's password.
getKeyStoreDescriptor() - Method in interface org.refcodes.security.KeyStoreDescriptorAccessor
Retrieves the KeyStoreDescriptor from the KeyStoreDescriptor property.
getName() - Method in enum class org.refcodes.security.Algorithm
getPatternArguments() - Method in exception class org.refcodes.security.DecryptEncodingException
getPatternArguments() - Method in exception class org.refcodes.security.EncryptEncodingException
getStoreFile() - Method in class org.refcodes.security.TrustStoreDescriptor
Retrieves the File pointing to the KeyStore.
getStorePassword() - Method in class org.refcodes.security.TrustStoreDescriptor
Retrieves the keysotre's password.
getStoreType() - Method in class org.refcodes.security.TrustStoreDescriptor
Retrieves the StoreType representing the type of the KeyStore.
getTrustStoreDescriptor() - Method in interface org.refcodes.security.TrustStoreDescriptorAccessor
Retrieves the TrustStoreDescriptor from the TrustStoreDescriptor property.

H

hashCode() - Method in class org.refcodes.security.DecryptionInputStream
hashCode() - Method in class org.refcodes.security.EncryptionOutputStream

J

JCEKS - Enum constant in enum class org.refcodes.security.StoreType
"...
JCERACFKS - Enum constant in enum class org.refcodes.security.StoreType
"...
JKS - Enum constant in enum class org.refcodes.security.StoreType
 

K

KeyStoreDescriptor - Class in org.refcodes.security
The immutable KeyStoreDescriptor implements the TrustStoreDescriptor interface.
KeyStoreDescriptor(File) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptor(File, char[]) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptor(File, char[], char[]) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptor(File, StoreType) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptor(File, StoreType, char[]) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptor(File, StoreType, char[], char[]) - Constructor for class org.refcodes.security.KeyStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
KeyStoreDescriptorAccessor - Interface in org.refcodes.security
Provides an accessor for a KeyStoreDescriptor property.
KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B> - Interface in org.refcodes.security
Provides a builder method for a KeyStoreDescriptor property returning the builder for applying multiple build operations.
KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator - Interface in org.refcodes.security
Provides a mutator for a KeyStoreDescriptor property.
KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty - Interface in org.refcodes.security
Provides a KeyStoreDescriptor property.

L

letKeyStoreDescriptor(KeyStoreDescriptor) - Method in interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given KeyStoreDescriptor (setter) as of KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator.setKeyStoreDescriptor(KeyStoreDescriptor) and returns the very same value (getter).
letTrustStoreDescriptor(TrustStoreDescriptor) - Method in interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the given TrustStoreDescriptor (setter) as of TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator.setTrustStoreDescriptor(TrustStoreDescriptor) and returns the very same value (getter).

M

mark(int) - Method in class org.refcodes.security.DecryptionInputStream
markSupported() - Method in class org.refcodes.security.DecryptionInputStream

O

org.refcodes.security - module org.refcodes.security
 
org.refcodes.security - package org.refcodes.security
This artifact provides the basic interfaces (and supporting classes) to implement vanilla plain cryptographic algorithms (as of the Encrypter or Decrypter types) for you to experiment with cryptography and afterwards (optionally) link your algorithms to the JCA (Java Cryptography Architecture).

P

PasswordTextDecrypter - Class in org.refcodes.security
The PasswordTextDecrypter is a text Decrypter for decrypting String instances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.
PasswordTextDecrypter(char[]) - Constructor for class org.refcodes.security.PasswordTextDecrypter
Constructs a PasswordTextDecrypter instance with the given password.
PasswordTextDecrypter(String) - Constructor for class org.refcodes.security.PasswordTextDecrypter
Constructs a PasswordTextDecrypter instance with the given password.
PasswordTextEncrypter - Class in org.refcodes.security
The PasswordTextEncrypter is a text Encrypter for encrypting String instances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.
PasswordTextEncrypter(char[]) - Constructor for class org.refcodes.security.PasswordTextEncrypter
Constructs a PasswordTextEncrypter instance with the given password.
PasswordTextEncrypter(String) - Constructor for class org.refcodes.security.PasswordTextEncrypter
Constructs a PasswordTextEncrypter instance with the given password.
PKCS12 - Enum constant in enum class org.refcodes.security.StoreType
"...
PKCS12S2 - Enum constant in enum class org.refcodes.security.StoreType
"...

R

read() - Method in class org.refcodes.security.DecryptionInputStream
read(byte[]) - Method in class org.refcodes.security.DecryptionInputStream
read(byte[], int, int) - Method in class org.refcodes.security.DecryptionInputStream
reset() - Method in class org.refcodes.security.DecryptionInputStream
RSA - Enum constant in enum class org.refcodes.security.Algorithm
 

S

SecurityException - Exception Class in org.refcodes.security
SecurityException(String) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityException(String, String) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityException(String, Throwable) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityException(String, Throwable, String) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityException(Throwable) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityException(Throwable, String) - Constructor for exception class org.refcodes.security.SecurityException
 
SecurityRuntimeException - Exception Class in org.refcodes.security
The Class SecurityRuntimeException.
SecurityRuntimeException(String) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
SecurityRuntimeException(String, String) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
SecurityRuntimeException(String, Throwable) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
SecurityRuntimeException(String, Throwable, String) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
SecurityRuntimeException(Throwable) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
SecurityRuntimeException(Throwable, String) - Constructor for exception class org.refcodes.security.SecurityRuntimeException
 
setKeyStoreDescriptor(KeyStoreDescriptor) - Method in interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator
Sets the KeyStoreDescriptor for the KeyStoreDescriptor property.
setTrustStoreDescriptor(TrustStoreDescriptor) - Method in interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator
Sets the TrustStoreDescriptor for the TrustStoreDescriptor property.
skip(long) - Method in class org.refcodes.security.DecryptionInputStream
StoreType - Enum Class in org.refcodes.security
The Enum StoreType.

T

toDecrypted(byte[], int, int, byte[], int) - Method in interface org.refcodes.security.Decrypter
For compatibility with the java.security framework, ehttps://www.metacodes.proly to be integrated in a sub-class of the CipherSpi.
toDecrypted(byte[], int, int, byte[], int) - Method in class org.refcodes.security.PasswordTextDecrypter
For compatibility with the java.security framework, ehttps://www.metacodes.proly to be integrated in a sub-class of the CipherSpi.
toDecrypted(ENC) - Method in interface org.refcodes.security.Decrypter
You pass in data of a given type and you get decrypted data of (another) given type.
toDecrypted(String) - Method in class org.refcodes.security.PasswordTextDecrypter
You pass in data of a given type and you get decrypted data of (another) given type.
toEncrypted(byte[], int, int, byte[], int) - Method in interface org.refcodes.security.Encrypter
For compatibility with the java.security framework and easily to be integrated in a sub-class of the CipherSpi.
toEncrypted(byte[], int, int, byte[], int) - Method in class org.refcodes.security.PasswordTextEncrypter
For compatibility with the java.security framework and easily to be integrated in a sub-class of the CipherSpi.
toEncrypted(DEC) - Method in interface org.refcodes.security.Encrypter
You pass in data of a given type and you get encrypted data of (another) given type.
toEncrypted(String) - Method in class org.refcodes.security.PasswordTextEncrypter
You pass in data of a given type and you get encrypted data of (another) given type.
toString() - Method in class org.refcodes.security.DecryptionInputStream
toString() - Method in class org.refcodes.security.EncryptionOutputStream
TrustStoreDescriptor - Class in org.refcodes.security
Describes the data required to access a truststore.
TrustStoreDescriptor(File) - Constructor for class org.refcodes.security.TrustStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
TrustStoreDescriptor(File, char[]) - Constructor for class org.refcodes.security.TrustStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
TrustStoreDescriptor(File, StoreType) - Constructor for class org.refcodes.security.TrustStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
TrustStoreDescriptor(File, StoreType, char[]) - Constructor for class org.refcodes.security.TrustStoreDescriptor
Constructs a KeyStoreDescriptor with the data required to access a KeyStore.
TrustStoreDescriptorAccessor - Interface in org.refcodes.security
Provides an accessor for a TrustStoreDescriptor property.
TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B> - Interface in org.refcodes.security
Provides a builder method for a TrustStoreDescriptor property returning the builder for applying multiple build operations.
TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator - Interface in org.refcodes.security
Provides a mutator for a TrustStoreDescriptor property.
TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty - Interface in org.refcodes.security
Provides a TrustStoreDescriptor property.

V

valueOf(String) - Static method in enum class org.refcodes.security.Algorithm
Returns the enum constant of this class with the specified name.
valueOf(String) - Static method in enum class org.refcodes.security.StoreType
Returns the enum constant of this class with the specified name.
values() - Static method in enum class org.refcodes.security.Algorithm
Returns an array containing the constants of this enum class, in the order they are declared.
values() - Static method in enum class org.refcodes.security.StoreType
Returns an array containing the constants of this enum class, in the order they are declared.

W

withKeyStoreDescriptor(KeyStoreDescriptor) - Method in interface org.refcodes.security.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder
Sets the KeyStoreDescriptor for the KeyStoreDescriptor property.
withTrustStoreDescriptor(TrustStoreDescriptor) - Method in interface org.refcodes.security.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder
Sets the TrustStoreDescriptor for the TrustStoreDescriptor property.
write(byte[]) - Method in class org.refcodes.security.EncryptionOutputStream
write(byte[], int, int) - Method in class org.refcodes.security.EncryptionOutputStream
write(int) - Method in class org.refcodes.security.EncryptionOutputStream

_

_encoding - Variable in exception class org.refcodes.security.DecryptEncodingException
 
_encoding - Variable in exception class org.refcodes.security.EncryptEncodingException
 
A C D E F G H J K L M O P R S T V W _ 
All Classes and Interfaces|All Packages|Serialized Form