Class EncryptionException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.security.SecurityException
org.refcodes.security.EncryptionException
- All Implemented Interfaces:
Serializable, org.refcodes.exception.ErrorCodeAccessor, org.refcodes.exception.Trap
- Direct Known Subclasses:
EncryptEncodingException
Thrown in case an encryption issue occurred regarding the
Encrypter.- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classThrown in case an encryption issue occurred regarding theEncrypter.Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionEncryptionException(String aMessage) EncryptionException(String aMessage, String aErrorCode) EncryptionException(String aMessage, Throwable aCause) EncryptionException(String aMessage, Throwable aCause, String aErrorCode) EncryptionException(Throwable aCause) EncryptionException(Throwable aCause, String aErrorCode) -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
EncryptionException
-
EncryptionException
-
EncryptionException
-
EncryptionException
-
EncryptionException
-
EncryptionException
-