Class EncryptionOutputStream
java.lang.Object
java.io.OutputStream
org.refcodes.security.EncryptionOutputStream
- All Implemented Interfaces:
Closeable,Flushable,AutoCloseable,org.refcodes.mixin.Disposable
A
EncryptionOutputStream wraps an OutputStream and produces
output bytes by applying a Encrypter on each byte to be written
before delegating the processed vale to the given OutputStream. The
output of the EncryptionOutputStream can be converted back by the
according DecryptionInputStream.-
Constructor Summary
ConstructorsConstructorDescriptionEncryptionOutputStream(OutputStream aOutputStream, Encrypter<byte[], byte[], EncryptionException> aEncrypter) Constructs theEncryptionOutputStreamby wrapping the givenOutputStreamfor the providedEncrypterto be applied on the bytes to be written. -
Method Summary
Methods inherited from class java.io.OutputStream
nullOutputStream
-
Constructor Details
-
EncryptionOutputStream
public EncryptionOutputStream(OutputStream aOutputStream, Encrypter<byte[], byte[], EncryptionException> aEncrypter) Constructs theEncryptionOutputStreamby wrapping the givenOutputStreamfor the providedEncrypterto be applied on the bytes to be written.- Parameters:
aOutputStream- TheOutputStreamto be wrapped.aEncrypter- TheEncrypterto be applied to the bytes to be written.
-
-
Method Details
-
equals
-
flush
- Specified by:
flushin interfaceFlushable- Overrides:
flushin classOutputStream- Throws:
IOException
-
hashCode
-
write
- Specified by:
writein classOutputStream- Throws:
IOException
-
write
- Overrides:
writein classOutputStream- Throws:
IOException
-
write
- Overrides:
writein classOutputStream- Throws:
IOException
-
close
- Specified by:
closein interfaceAutoCloseable- Specified by:
closein interfaceCloseable- Overrides:
closein classOutputStream- Throws:
IOException
-
dispose
public void dispose()- Specified by:
disposein interfaceorg.refcodes.mixin.Disposable
-
toString
-