- All Superinterfaces:
TrustStoreDescriptor
- All Known Subinterfaces:
KeyStoreDescriptor.KeyStoreDescriptorBuilder
- All Known Implementing Classes:
KeyStoreDescriptorBuilderImpl,KeyStoreDescriptorImpl
Describes the data required to access a
KeyStore.The KeyStore
is used to decide which authentication credentials should be sent to the
remote host for authentication during SSL handshake. If you are an SSL Server
you will use a private key during key exchange algorithm and send
certificates corresponding to your public keys to client, this certificate is
acquired from KeyStore.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceThe mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.Nested classes/interfaces inherited from interface org.refcodes.security.TrustStoreDescriptor
TrustStoreDescriptor.TrustStoreDescriptorBuilder -
Method Summary
Methods inherited from interface org.refcodes.security.TrustStoreDescriptor
getStoreFile, getStorePassword, getStoreType
-
Method Details
-
getKeyPassword
String getKeyPassword()Retrieves the key's password.- Returns:
- The key password.
-