Uses of Interface
org.refcodes.security.Decrypter
-
-
Uses of Decrypter in org.refcodes.security
Subinterfaces of Decrypter in org.refcodes.security Modifier and Type Interface Description interfaceCrypter<ENC,DEC,ENCEXC extends EncryptionException,DECEXC extends DecryptionException>Constructors in org.refcodes.security with parameters of type Decrypter Constructor Description DecryptionInputStream(InputStream aInputStream, Decrypter<byte[],byte[],DecryptionException> aDecrypter)Constructs theDecryptionInputStreamby wrapping the givenInputStreamfor the providedDecrypterto be applied on the bytes to be read.
-