Uses of Class
org.refcodes.security.DecryptionException
-
Uses of DecryptionException in org.refcodes.security
Classes in org.refcodes.security with type parameters of type DecryptionExceptionModifier and TypeInterfaceDescriptioninterfaceCrypter<ENC,DEC, ENCEXC extends EncryptionException, DECEXC extends DecryptionException> interfaceDecrypter<DEC,ENC, EXC extends DecryptionException> Plain interface for providing straight forward decryption functionality as ofDecrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Subclasses of DecryptionException in org.refcodes.securityModifier and TypeClassDescriptionclassThrown in case an decryption issue occurred regarding the encoding.Classes in org.refcodes.security that implement interfaces with type arguments of type DecryptionExceptionModifier and TypeClassDescriptionclassThePasswordTextDecrypteris a textDecrypterfor decryptingStringinstances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.Methods in org.refcodes.security that throw DecryptionExceptionModifier and TypeMethodDescriptiondefault intDecrypter.decrypt(byte[] aBuffer) This method decrypts the provided buffer.default intDecrypter.decrypt(byte[] aBuffer, int aOffset, int aLength) This method decrypts the provided buffer beginning at the given offset and the given number of bytes.intDecrypter.toDecrypted(byte[] aBuffer, int aOffset, int aLength, byte[] aOutBuffer, int aOutOffset) For compatibility with the java.security framework, ehttps://www.metacodes.proly to be integrated in a sub-class of theCipherSpi.Decrypter.toDecrypted(ENC aInput) You pass in data of a given type and you get decrypted data of (another) given type.intPasswordTextDecrypter.toDecrypted(byte[] aBuffer, int aOffset, int aLength, byte[] aOutBuffer, int aOutOffset) For compatibility with the java.security framework, ehttps://www.metacodes.proly to be integrated in a sub-class of theCipherSpi.PasswordTextDecrypter.toDecrypted(String aInput) You pass in data of a given type and you get decrypted data of (another) given type.Constructor parameters in org.refcodes.security with type arguments of type DecryptionExceptionModifierConstructorDescriptionDecryptionInputStream(InputStream aInputStream, Decrypter<byte[], byte[], DecryptionException> aDecrypter) Constructs theDecryptionInputStreamby wrapping the givenInputStreamfor the providedDecrypterto be applied on the bytes to be read.