Uses of Interface
org.refcodes.security.Encrypter
-
-
Uses of Encrypter in org.refcodes.security
Subinterfaces of Encrypter in org.refcodes.security Modifier and Type Interface Description interfaceCrypter<ENC,DEC,ENCEXC extends EncryptionException,DECEXC extends DecryptionException>Fields in org.refcodes.security declared as Encrypter Modifier and Type Field Description protected Encrypter<byte[],byte[],EncryptionException>EncryptionOutputStream. _encrypterConstructors in org.refcodes.security with parameters of type Encrypter Constructor Description EncryptionOutputStream(OutputStream aOutputStream, Encrypter<byte[],byte[],EncryptionException> aEncrypter)Constructs theEncryptionOutputStreamby wrapping the givenOutputStreamfor the providedEncrypterto be applied on the bytes to be written.
-