Uses of Class
org.refcodes.security.EncryptionException
-
Uses of EncryptionException in org.refcodes.security
Classes in org.refcodes.security with type parameters of type EncryptionExceptionModifier and TypeInterfaceDescriptioninterfaceCrypter<ENC,DEC, ENCEXC extends EncryptionException, DECEXC extends DecryptionException> interfaceEncrypter<ENC,DEC, EXC extends EncryptionException> Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Subclasses of EncryptionException in org.refcodes.securityModifier and TypeClassDescriptionclassThrown in case an encryption issue occurred regarding the encoding.Classes in org.refcodes.security that implement interfaces with type arguments of type EncryptionExceptionModifier and TypeClassDescriptionclassThePasswordTextEncrypteris a textEncrypterfor encryptingStringinstances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.Methods in org.refcodes.security that throw EncryptionExceptionModifier and TypeMethodDescriptiondefault intEncrypter.encrypt(byte[] aBuffer) This method encrypts the provided buffer.default intEncrypter.encrypt(byte[] aBuffer, int aOffset, int aLength) This method encrypts the provided buffer beginning at the given offset and the given number of bytes.intEncrypter.toEncrypted(byte[] aBuffer, int aOffset, int aLength, byte[] aOutBuffer, int aOutOffset) For compatibility with the java.security framework and easily to be integrated in a sub-class of theCipherSpi.Encrypter.toEncrypted(DEC aInput) You pass in data of a given type and you get encrypted data of (another) given type.intPasswordTextEncrypter.toEncrypted(byte[] aBuffer, int aOffset, int aLength, byte[] aOutBuffer, int aOutOffset) For compatibility with the java.security framework and easily to be integrated in a sub-class of theCipherSpi.PasswordTextEncrypter.toEncrypted(String aInput) You pass in data of a given type and you get encrypted data of (another) given type.Constructor parameters in org.refcodes.security with type arguments of type EncryptionExceptionModifierConstructorDescriptionEncryptionOutputStream(OutputStream aOutputStream, Encrypter<byte[], byte[], EncryptionException> aEncrypter) Constructs theEncryptionOutputStreamby wrapping the givenOutputStreamfor the providedEncrypterto be applied on the bytes to be written.