Uses of Class
org.refcodes.security.SecurityException
-
Uses of SecurityException in org.refcodes.security
Subclasses of SecurityException in org.refcodes.securityModifier and TypeClassDescriptionclassThrown in case an decryption issue occurred regarding the encoding.classThrown in case an decryption issue occurred regarding theEncrypter.classThrown in case an encryption issue occurred regarding the encoding.classThrown in case an encryption issue occurred regarding theEncrypter.