Uses of Class
org.refcodes.security.SecurityRuntimeException
-
-
Uses of SecurityRuntimeException in org.refcodes.security
Subclasses of SecurityRuntimeException in org.refcodes.security Modifier and Type Class Description static classDecryptionException.DecryptionRuntimeExceptionThrown in case an decryption issue occurred regarding theEncrypter.static classEncryptionException.EncryptionRuntimeExceptionThrown in case an encryption issue occurred regarding theEncrypter.
-