Package org.refcodes.security
package org.refcodes.security
This artifact provides the basic interfaces (and supporting classes) to
implement vanilla plain cryptographic algorithms (as of the
Encrypter or
Decrypter types) for you to experiment with
cryptography and afterwards (optionally) link your algorithms to the JCA (Java
Cryptography Architecture).
Please refer to the refcodes-security: Chaos-based encryption as Java cryptographic extension (and without) documentation for an up-to-date and detailed description on the usage of this artifact.
-
ClassDescriptionThe Enum Algorithm.Thrown in case an decryption issue occurred regarding the encoding.Decrypter<DEC, ENC, EXC extends DecryptionException>Plain interface for providing straight forward decryption functionality as of
Decrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Thrown in case an decryption issue occurred regarding theEncrypter.Thrown in case an decryption issue occurred regarding theEncrypter.ADecryptionInputStreamwraps anInputStreamand consumes input bytes by applying aDecrypteron each byte read from the providedInputStreambefore passing back the processed byte to the caller.Thrown in case an encryption issue occurred regarding the encoding.Encrypter<ENC, DEC, EXC extends EncryptionException>Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Thrown in case an encryption issue occurred regarding theEncrypter.Thrown in case an encryption issue occurred regarding theEncrypter.AEncryptionOutputStreamwraps anOutputStreamand produces output bytes by applying aEncrypteron each byte to be written before delegating the processed vale to the givenOutputStream.The mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.Provides an accessor for aKeyStoreDescriptorproperty.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>Provides a builder method for aKeyStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aKeyStoreDescriptorproperty.Provides aKeyStoreDescriptorproperty.Implementation of theKeyStoreDescriptorinterface.The immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.ThePasswordTextDecrypteris a textDecrypterfor decryptingStringinstances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.ThePasswordTextEncrypteris a textEncrypterfor encryptingStringinstances with a given password using a "PBKDF2WithHmacSHA256" key factory and a "AES/CBC/PKCS5Padding" cipher.The ClassSecurityException.The Class SecurityRuntimeException.The Enum StoreType.Describes the data required to access a truststore.The mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.Provides an accessor for aTrustStoreDescriptorproperty.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>Provides a builder method for aTrustStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aTrustStoreDescriptorproperty.Provides aTrustStoreDescriptorproperty.Implementation of theKeyStoreDescriptorinterface.The immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface.