Uses of Package
org.refcodes.security
-
Classes in org.refcodes.security used by org.refcodes.securityClassDescriptionThe Enum Algorithm.Plain interface for providing straight forward decryption functionality as of
Decrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Thrown in case an decryption issue occurred regarding theEncrypter.Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Thrown in case an encryption issue occurred regarding theEncrypter.The mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.Provides an accessor for aKeyStoreDescriptorproperty.Provides a builder method for aKeyStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aKeyStoreDescriptorproperty.The ClassSecurityException.The Class SecurityRuntimeException.The Enum StoreType.Describes the data required to access a truststore.The mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.Provides an accessor for aTrustStoreDescriptorproperty.Provides a builder method for aTrustStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aTrustStoreDescriptorproperty.Implementation of theKeyStoreDescriptorinterface.