TrustStoreDescriptorKeyStoreDescriptor.KeyStoreDescriptorBuilderKeyStoreDescriptorBuilderImpl, KeyStoreDescriptorImplpublic interface KeyStoreDescriptor extends TrustStoreDescriptor
KeyStore.The KeyStore
is used to decide which authentication credentials should be sent to the
remote host for authentication during SSL handshake. If you are an SSL Server
you will use a private key during key exchange algorithm and send
certificates corresponding to your public keys to client, this certificate is
acquired from KeyStore.| Modifier and Type | Interface | Description |
|---|---|---|
static interface |
KeyStoreDescriptor.KeyStoreDescriptorBuilder |
The mutable
KeyStoreDescriptor.KeyStoreDescriptorBuilder extends the
KeyStoreDescriptor with manipulator methods. |
TrustStoreDescriptor.TrustStoreDescriptorBuilder| Modifier and Type | Method | Description |
|---|---|---|
String |
getKeyPassword() |
Retrieves the key's password.
|
getStoreFile, getStorePassword, getStoreTypeString getKeyPassword()
Copyright © 2018. All rights reserved.