Uses of Class
org.refcodes.security.DecryptionException
-
-
Uses of DecryptionException in org.refcodes.security
Classes in org.refcodes.security with type parameters of type DecryptionException Modifier and Type Interface Description interfaceDecrypter<DEC,ENC,EXC extends DecryptionException>Plain interface for providing straight forward decryption functionality as ofDecrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Methods in org.refcodes.security that throw DecryptionException Modifier and Type Method Description intDecrypter. toDecrypted(byte[] aInput, int aInputOffset, int aInputLength, byte[] aOutput, int aOutputOffset)For compatibility with the java.security framework, especially to be integrated in a sub-class of theCipherSpi.DECDecrypter. toDecrypted(ENC aInput)You pass in data of a given type and you get decrypted data of (another) given type.
-