Uses of Class
org.refcodes.security.EncryptionException
-
-
Uses of EncryptionException in org.refcodes.security
Classes in org.refcodes.security with type parameters of type EncryptionException Modifier and Type Interface Description interfaceEncrypter<ENC,DEC,EXC extends EncryptionException>Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Methods in org.refcodes.security that throw EncryptionException Modifier and Type Method Description intEncrypter. toEncrypted(byte[] aInput, int aInputOffset, int aInputLength, byte[] aOutput, int aOutputOffset)For compatibility with the java.security framework, especially to be integrated in a sub-class of theCipherSpi.ENCEncrypter. toEncrypted(DEC aInput)You pass in data of a given type and you get encrypted data of (another) given type.
-