Uses of Interface
org.refcodes.security.TrustStoreDescriptor
-
-
Uses of TrustStoreDescriptor in org.refcodes.security
Subinterfaces of TrustStoreDescriptor in org.refcodes.security Modifier and Type Interface Description interfaceKeyStoreDescriptorDescribes the data required to access aKeyStore.TheKeyStoreis used to decide which authentication credentials should be sent to the remote host for authentication during SSL handshake.static interfaceKeyStoreDescriptor.KeyStoreDescriptorBuilderThe mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.static interfaceTrustStoreDescriptor.TrustStoreDescriptorBuilderThe mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.Classes in org.refcodes.security that implement TrustStoreDescriptor Modifier and Type Class Description classKeyStoreDescriptorBuilderImplImplementation of theKeyStoreDescriptorinterface.classKeyStoreDescriptorImplThe immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.classTrustStoreDescriptorBuilderImplImplementation of theKeyStoreDescriptorinterface.classTrustStoreDescriptorImplThe immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface.Methods in org.refcodes.security that return TrustStoreDescriptor Modifier and Type Method Description TrustStoreDescriptorTrustStoreDescriptorAccessor. getTrustStoreDescriptor()Retrieves theTrustStoreDescriptorfrom theTrustStoreDescriptorproperty.Methods in org.refcodes.security with parameters of type TrustStoreDescriptor Modifier and Type Method Description voidTrustStoreDescriptorAccessor.TrustStoreDescriptorMutator. setTrustStoreDescriptor(TrustStoreDescriptor aStoreDescriptor)Sets theTrustStoreDescriptorfor theTrustStoreDescriptorproperty.BTrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder. withTrustStoreDescriptor(TrustStoreDescriptor aStoreDescriptor)Sets theTrustStoreDescriptorfor theTrustStoreDescriptorproperty.
-