Package org.refcodes.security
-
Interface Summary Interface Description Decrypter<DEC,ENC,EXC extends DecryptionException> Plain interface for providing straight forward decryption functionality as ofDecrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Encrypter<ENC,DEC,EXC extends EncryptionException> Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).KeyStoreDescriptor Describes the data required to access aKeyStore.TheKeyStoreis used to decide which authentication credentials should be sent to the remote host for authentication during SSL handshake.KeyStoreDescriptor.KeyStoreDescriptorBuilder The mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.KeyStoreDescriptorAccessor Provides an accessor for aKeyStoreDescriptorproperty.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>> Provides a builder method for aKeyStoreDescriptorproperty returning the builder for applying multiple build operations.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator Provides a mutator for aKeyStoreDescriptorproperty.KeyStoreDescriptorAccessor.KeyStoreDescriptorProperty Provides aKeyStoreDescriptorproperty.TrustStoreDescriptor Describes the data required to access a truststore.TrustStoreDescriptor.TrustStoreDescriptorBuilder The mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.TrustStoreDescriptorAccessor Provides an accessor for aTrustStoreDescriptorproperty.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>> Provides a builder method for aTrustStoreDescriptorproperty returning the builder for applying multiple build operations.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator Provides a mutator for aTrustStoreDescriptorproperty.TrustStoreDescriptorAccessor.TrustStoreDescriptorProperty Provides aTrustStoreDescriptorproperty. -
Class Summary Class Description KeyStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.KeyStoreDescriptorImpl The immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.SecurityUtility The Class SecurityUtility.TrustStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.TrustStoreDescriptorImpl The immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface. -
Enum Summary Enum Description Algorithm The Enum Algorithm.StoreType -
Exception Summary Exception Description DecryptionException Thrown in case an encryption issue occurred regarding theEncrypter.EncryptionException Thrown in case a decryption issue occurred regarding theDecrypter.SecurityException The Class SecurityException.