| Algorithm |
The Enum Algorithm.
|
| DecryptionException |
Thrown in case an encryption issue occurred regarding the Encrypter.
|
| EncryptionException |
Thrown in case a decryption issue occurred regarding the Decrypter.
|
| KeyStoreDescriptor |
Describes the data required to access a KeyStore.The KeyStore
is used to decide which authentication credentials should be sent to the
remote host for authentication during SSL handshake.
|
| KeyStoreDescriptor.KeyStoreDescriptorBuilder |
|
| KeyStoreDescriptorAccessor |
|
| KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder |
Provides a builder method for a KeyStoreDescriptor property
returning the builder for applying multiple build operations.
|
| KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator |
|
| SecurityException |
The Class SecurityException.
|
| StoreType |
|
| TrustStoreDescriptor |
Describes the data required to access a truststore.
|
| TrustStoreDescriptor.TrustStoreDescriptorBuilder |
|
| TrustStoreDescriptorAccessor |
|
| TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder |
Provides a builder method for a TrustStoreDescriptor property
returning the builder for applying multiple build operations.
|
| TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator |
|
| TrustStoreDescriptorBuilderImpl |
|