All Classes and Interfaces
Class
Description
The Enum Algorithm.
Plain interface for providing straight forward decryption functionality as of
Decrypter.toDecrypted(Object) and for forcing your plain functionality to
provide a bridge to the Java Cryptographic Extension (JCE) framework's
CipherSpi as of Decrypter.toDecrypted(byte[], int, int, byte[], int).Thrown in case an decryption issue occurred regarding the
Encrypter.Thrown in case an decryption issue occurred regarding the
Encrypter.A
DecryptionInputStream wraps an InputStream and consumes
input bytes by applying a Decrypter on each byte read from the
provided InputStream before passing back the processed byte to the
caller.Plain interface for providing straight forward encryption functionality as of
toEncrypted(Object) and for forcing your plain functionality to
provide a bridge to the Java Cryptographic Extension (JCE) framework's
CipherSpi as of toEncrypted(byte[], int, int, byte[], int).Thrown in case an encryption issue occurred regarding the
Encrypter.Thrown in case an encryption issue occurred regarding the
Encrypter.A
EncryptionOutputStream wraps an OutputStream and produces
output bytes by applying a Encrypter on each byte to be written
before delegating the processed vale to the given OutputStream.The mutable
KeyStoreDescriptor.KeyStoreDescriptorBuilder extends the
KeyStoreDescriptor with manipulator methods.Provides an accessor for a
KeyStoreDescriptor property.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>
Provides a builder method for a
KeyStoreDescriptor property
returning the builder for applying multiple build operations.Provides a mutator for a
KeyStoreDescriptor property.Provides a
KeyStoreDescriptor property.Implementation of the
KeyStoreDescriptor interface.The immutable
KeyStoreDescriptorImpl implements the
TrustStoreDescriptor interface.The Class SecurityException.
The Class SecurityUtility.
Describes the data required to access a truststore.
The mutable
TrustStoreDescriptor.TrustStoreDescriptorBuilder extends the
TrustStoreDescriptor with manipulator methods.Provides an accessor for a
TrustStoreDescriptor property.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>
Provides a builder method for a
TrustStoreDescriptor property
returning the builder for applying multiple build operations.Provides a mutator for a
TrustStoreDescriptor property.Provides a
TrustStoreDescriptor property.Implementation of the
KeyStoreDescriptor interface.The immutable
TrustStoreDescriptorImpl implements the
TrustStoreDescriptor interface.