java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.security.SecurityException
org.refcodes.security.EncryptionException
- All Implemented Interfaces:
Serializable,org.refcodes.exception.ErrorCodeAccessor,org.refcodes.exception.Trap
Thrown in case an encryption issue occurred regarding the
Encrypter.- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classThrown in case an encryption issue occurred regarding theEncrypter.Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B extends org.refcodes.exception.ErrorCodeAccessor.ErrorCodeBuilder<B>>, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeMutator, org.refcodes.exception.ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionEncryptionException(String aMessage) Instantiates a new encryption exception.EncryptionException(String aMessage, String aErrorCode) Instantiates a new encryption exception.EncryptionException(String aMessage, Throwable aCause) Instantiates a new encryption exception.EncryptionException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new encryption exception.EncryptionException(Throwable aCause) Instantiates a new encryption exception.EncryptionException(Throwable aCause, String aErrorCode) Instantiates a new encryption exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
EncryptionException
Instantiates a new encryption exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
EncryptionException
Instantiates a new encryption exception. -
EncryptionException
Instantiates a new encryption exception. -
EncryptionException
Instantiates a new encryption exception.- Parameters:
aMessage- The aMessage describing this exception.
-
EncryptionException
Instantiates a new encryption exception. -
EncryptionException
Instantiates a new encryption exception.
-