Class TrustStoreDescriptor
java.lang.Object
org.refcodes.security.TrustStoreDescriptor
- All Implemented Interfaces:
org.refcodes.mixin.Disposable
- Direct Known Subclasses:
KeyStoreDescriptor
Describes the data required to access a truststore. A truststore stores
certificates from third party to identify third party and signed by
certificate authorities such as "Verisign", "Thawte", or "GoDaddy". A client
will use certificates stored in a truststore to verify the identity of a
server.
-
Constructor Summary
ConstructorsConstructorDescriptionTrustStoreDescriptor(File aStoreFile) Constructs aKeyStoreDescriptorwith the data required to access aKeyStore.TrustStoreDescriptor(File aStoreFile, char[] aStorePassword) Constructs aKeyStoreDescriptorwith the data required to access aKeyStore.TrustStoreDescriptor(File aStoreFile, StoreType aStoreType) Constructs aKeyStoreDescriptorwith the data required to access aKeyStore.TrustStoreDescriptor(File aStoreFile, StoreType aStoreType, char[] aStorePassword) Constructs aKeyStoreDescriptorwith the data required to access aKeyStore. -
Method Summary
-
Constructor Details
-
TrustStoreDescriptor
Constructs aKeyStoreDescriptorwith the data required to access aKeyStore. TheStoreTypedefaults toStoreType.JKS.- Parameters:
aStoreFile- The keystoreFile.
-
TrustStoreDescriptor
-
TrustStoreDescriptor
Constructs aKeyStoreDescriptorwith the data required to access aKeyStore.- Parameters:
aStoreFile- The keystoreFile.aStorePassword- The keystore password.
-
TrustStoreDescriptor
-
-
Method Details
-
getStoreFile
-
getStoreType
-
getStorePassword
-
dispose
public void dispose()Note: The passwords are overwritten with zeros and all fields are set to null: The instance will not be usable afterwards.
- Specified by:
disposein interfaceorg.refcodes.mixin.Disposable
-