Interface TrustStoreDescriptor
- All Known Subinterfaces:
KeyStoreDescriptor, KeyStoreDescriptor.KeyStoreDescriptorBuilder, TrustStoreDescriptor.TrustStoreDescriptorBuilder
- All Known Implementing Classes:
KeyStoreDescriptorBuilderImpl, KeyStoreDescriptorImpl, TrustStoreDescriptorBuilderImpl, TrustStoreDescriptorImpl
public interface TrustStoreDescriptor
Describes the data required to access a truststore. A truststore stores
certificates from third party to identify third party and signed by
certificate authorities such as "Verisign", "Thawte", or "GoDaddy". A client
will use certificates stored in a truststore to verify the identity of a
server.
-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceThe mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the keysotre's password.
-
Method Details
-
getStoreFile
-
getStoreType
-
getStorePassword
-