-
- All Known Subinterfaces:
KeyStoreDescriptor,KeyStoreDescriptor.KeyStoreDescriptorBuilder,TrustStoreDescriptor.TrustStoreDescriptorBuilder
- All Known Implementing Classes:
KeyStoreDescriptorBuilderImpl,KeyStoreDescriptorImpl,TrustStoreDescriptorBuilderImpl,TrustStoreDescriptorImpl
public interface TrustStoreDescriptorDescribes the data required to access a truststore. A truststore stores certificates from third party to identify third party and signed by certificate authorities such as "Verisign", "Thawte", or "GoDaddy". A client will use certificates stored in a truststore to verify the identity of a server.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceTrustStoreDescriptor.TrustStoreDescriptorBuilderThe mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description FilegetStoreFile()StringgetStorePassword()Retrieves the keysotre's password.StoreTypegetStoreType()
-