Uses of Class
org.refcodes.security.EncryptionException
-
Uses of EncryptionException in org.refcodes.security
Classes in org.refcodes.security with type parameters of type EncryptionException Modifier and Type Interface Description interfaceCrypter<ENC,DEC,ENCEXC extends EncryptionException,DECEXC extends DecryptionException>interfaceEncrypter<ENC,DEC,EXC extends EncryptionException>Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Methods in org.refcodes.security that throw EncryptionException Modifier and Type Method Description default intEncrypter. encrypt(byte[] aBuffer)This method encrypts the provided buffer.default intEncrypter. encrypt(byte[] aBuffer, int aOffset, int aLength)This method encrypts the provided buffer beginning sat the given offset and the given number of bytes.intEncrypter. toEncrypted(byte[] aBuffer, int aOffset, int aLength, byte[] aOutBuffer, int aOutOffset)For compatibility with the java.security framework, especially to be integrated in a sub-class of theCipherSpi.ENCEncrypter. toEncrypted(DEC aInput)You pass in data of a given type and you get encrypted data of (another) given type.Constructor parameters in org.refcodes.security with type arguments of type EncryptionException Constructor Description DecryptionOutputStream(OutputStream aOutputStream, Encrypter<byte[],byte[],EncryptionException> aEncrypter)Constructs theDecryptionOutputStreamby wrapping the givenOutputStreamfor the providedEncrypterto be applied on the bytes to be written.