Uses of Class
org.refcodes.security.SecurityException
-
Uses of SecurityException in org.refcodes.security
Subclasses of SecurityException in org.refcodes.security Modifier and Type Class Description classDecryptionExceptionThrown in case an encryption issue occurred regarding theEncrypter.classEncryptionExceptionThrown in case a decryption issue occurred regarding theDecrypter.