Module org.refcodes.security
Package org.refcodes.security
package org.refcodes.security
-
ClassDescriptionThe Enum Algorithm.Crypter<ENC,
DEC, ENCEXC extends EncryptionException, DECEXC extends DecryptionException> Decrypter<DEC,ENC, EXC extends DecryptionException> Plain interface for providing straight forward decryption functionality as ofDecrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).Thrown in case an decryption issue occurred regarding theEncrypter.Thrown in case an decryption issue occurred regarding theEncrypter.ADecryptionInputStreamwraps anInputStreamand consumes input bytes by applying aDecrypteron each byte read from the providedInputStreambefore passing back the processed byte to the caller.Encrypter<ENC,DEC, EXC extends EncryptionException> Plain interface for providing straight forward encryption functionality as ofEncrypter.toEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofEncrypter.toEncrypted(byte[], int, int, byte[], int).Thrown in case an encryption issue occurred regarding theEncrypter.Thrown in case an encryption issue occurred regarding theEncrypter.AEncryptionOutputStreamwraps anOutputStreamand produces output bytes by applying aEncrypteron each byte to be written before delegating the processed vale to the givenOutputStream.The mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.Provides an accessor for aKeyStoreDescriptorproperty.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B extends KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder<B>>Provides a builder method for aKeyStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aKeyStoreDescriptorproperty.Provides aKeyStoreDescriptorproperty.Implementation of theKeyStoreDescriptorinterface.The immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.The Class SecurityException.The Class SecurityUtility.Describes the data required to access a truststore.The mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.Provides an accessor for aTrustStoreDescriptorproperty.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B extends TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder<B>>Provides a builder method for aTrustStoreDescriptorproperty returning the builder for applying multiple build operations.Provides a mutator for aTrustStoreDescriptorproperty.Provides aTrustStoreDescriptorproperty.Implementation of theKeyStoreDescriptorinterface.The immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface.