Module org.refcodes.security
Package org.refcodes.security
-
Class Summary Class Description DecryptionInputStream ADecryptionInputStreamwraps anInputStreamand consumes input bytes by applying aDecrypteron each byte read from the providedInputStreambefore passing back the processed byte to the caller.EncryptionOutputStream AEncryptionOutputStreamwraps anOutputStreamand produces output bytes by applying aEncrypteron each byte to be written before delegating the processed vale to the givenOutputStream.KeyStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.KeyStoreDescriptorImpl The immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.SecurityUtility The Class SecurityUtility.TrustStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.TrustStoreDescriptorImpl The immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface. -
Enum Summary Enum Description Algorithm The Enum Algorithm.StoreType -
Exception Summary Exception Description DecryptionException Thrown in case an encryption issue occurred regarding theEncrypter.EncryptionException Thrown in case an encryption issue occurred regarding theEncrypter.SecurityException The Class SecurityException.