Module org.refcodes.security
Package org.refcodes.security
-
-
Class Summary Class Description DecryptionOutputStream ADecryptionOutputStreamwraps anOutputStreamand produces output bytes by applying aEncrypteron each byte to be written before delegating the processed vale to the givenOutputStream.EncryptionInputStream AEncryptionInputStreamwraps anInputStreamand consumes input bytes by applying aDecrypteron each byte read from the providedInputStreambefore passing back the processed byte to the caller.KeyStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.KeyStoreDescriptorImpl The immutableKeyStoreDescriptorImplimplements theTrustStoreDescriptorinterface.SecurityUtility The Class SecurityUtility.TrustStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.TrustStoreDescriptorImpl The immutableTrustStoreDescriptorImplimplements theTrustStoreDescriptorinterface. -
Exception Summary Exception Description DecryptionException Thrown in case an encryption issue occurred regarding theEncrypter.EncryptionException Thrown in case a decryption issue occurred regarding theDecrypter.SecurityException The Class SecurityException.