Uses of Package
org.refcodes.security
-
Classes in org.refcodes.security used by org.refcodes.security Class Description Algorithm The Enum Algorithm.Decrypter Plain interface for providing straight forward decryption functionality as ofDecrypter.toDecrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias ofDecrypter.toDecrypted(byte[], int, int, byte[], int).DecryptionException Thrown in case an encryption issue occurred regarding theEncrypter.Encrypter Plain interface for providing straight forward encryption functionality as oftoEncrypted(Object)and for forcing your plain functionality to provide a bridge to the Java Cryptographic Extension (JCE) framework'sCipherSpias oftoEncrypted(byte[], int, int, byte[], int).EncryptionException Thrown in case a decryption issue occurred regarding theDecrypter.KeyStoreDescriptor KeyStoreDescriptor.KeyStoreDescriptorBuilder The mutableKeyStoreDescriptor.KeyStoreDescriptorBuilderextends theKeyStoreDescriptorwith manipulator methods.KeyStoreDescriptorAccessor Provides an accessor for aKeyStoreDescriptorproperty.KeyStoreDescriptorAccessor.KeyStoreDescriptorBuilder Provides a builder method for aKeyStoreDescriptorproperty returning the builder for applying multiple build operations.KeyStoreDescriptorAccessor.KeyStoreDescriptorMutator Provides a mutator for aKeyStoreDescriptorproperty.SecurityException The Class SecurityException.StoreType TrustStoreDescriptor Describes the data required to access a truststore.TrustStoreDescriptor.TrustStoreDescriptorBuilder The mutableTrustStoreDescriptor.TrustStoreDescriptorBuilderextends theTrustStoreDescriptorwith manipulator methods.TrustStoreDescriptorAccessor Provides an accessor for aTrustStoreDescriptorproperty.TrustStoreDescriptorAccessor.TrustStoreDescriptorBuilder Provides a builder method for aTrustStoreDescriptorproperty returning the builder for applying multiple build operations.TrustStoreDescriptorAccessor.TrustStoreDescriptorMutator Provides a mutator for aTrustStoreDescriptorproperty.TrustStoreDescriptorBuilderImpl Implementation of theKeyStoreDescriptorinterface.