DEC - the generic typeENC - the generic typeEXC - the generic typepublic interface Decrypter<DEC,ENC,EXC extends DecryptionException>
toDecrypted(Object) and for forcing your plain functionality to
provide a bridge to the Java Cryptographic Extension (JCE) framework's
CipherSpi as of toDecrypted(byte[], int, int, byte[], int).
This way you can use your algorithms outside the JCE framework. This may be
necessary when your Java's security settings prevent running your own JCE
extensions from inside an (Oracle-) unsigned JAR.| Modifier and Type | Method and Description |
|---|---|
int |
toDecrypted(byte[] aInput,
int aInputOffset,
int aInputLength,
byte[] aOutput,
int aOutputOffset)
For compatibility with the java.security framework, especially to be
integrated in a sub-class of the
CipherSpi. |
DEC |
toDecrypted(ENC aInput)
You pass in data of a given type and you get decrypted data of (another)
given type.
|
DEC toDecrypted(ENC aInput) throws EXC extends DecryptionException
aInput - The input data to be decrypted.EXC - Thrown in case something went wrong upon decryption.EXC extends DecryptionExceptionint toDecrypted(byte[] aInput,
int aInputOffset,
int aInputLength,
byte[] aOutput,
int aOutputOffset)
throws ShortBufferException,
DecryptionException
CipherSpi.aInput - The input to be decrypted.aInputOffset - The offset to start decryption.aInputLength - The length to be decryptedaOutput - The output where to decrypt to.aOutputOffset - The offset where to start writing the decrypted
output.ShortBufferException - In case you provided lengths and offsets not
fitting with the provided arrays.DecryptionException - Thrown in case a decryption issue occurred
regarding the Decrypter. Probably the configuration of
your Encrypter does not fit the one of the
Decrypter.Copyright © 2017. All rights reserved.