ENC - the generic typeDEC - the generic typeEXC - the generic typepublic interface Encrypter<ENC,DEC,EXC extends EncryptionException>
toEncrypted(Object) and for forcing your plain functionality to
provide a bridge to the Java Cryptographic Extension (JCE) framework's
CipherSpi as of toEncrypted(byte[], int, int, byte[], int).
This way you can use your algorithms outside the JCE framework. This may be
necessary when your Java's security settings prevent running your own JCE
extensions from inside an (Oracle-) unsigned JAR.| Modifier and Type | Method | Description |
|---|---|---|
int |
toEncrypted(byte[] aInput,
int aInputOffset,
int aInputLength,
byte[] aOutput,
int aOutputOffset) |
For compatibility with the java.security framework, especially to be
integrated in a sub-class of the
CipherSpi. |
ENC |
toEncrypted(DEC aInput) |
You pass in data of a given type and you get encrypted data of (another)
given type.
|
ENC toEncrypted(DEC aInput) throws EXC extends EncryptionException
aInput - The input data to be encrypted.EXC - Thrown in case something went wrong upon encryption.EXC extends EncryptionExceptionint toEncrypted(byte[] aInput,
int aInputOffset,
int aInputLength,
byte[] aOutput,
int aOutputOffset)
throws ShortBufferException,
EncryptionException
CipherSpi.aInput - The input to be encrypted.aInputOffset - The offset to start encryption.aInputLength - The length to be encryptedaOutput - The output where to encrypt to.aOutputOffset - The offset where to start writing the encrypted
output.ShortBufferException - In case you provided lengths and offsets not
fitting with the provided arrays.EncryptionException - Thrown in case an encryption issue occurred
regarding the Encrypter. Probably the configuration of
your Encrypter does not fit the one of the
Decrypter.Copyright © 2018. All rights reserved.